@@ -1,7 +1,7 @@
 # mkbackup-workflow.sh
 #
 
-WORKFLOW_mkbackuponly_DESCRIPTION="Backup system without creating a (new) rescue media."
+WORKFLOW_mkbackuponly_DESCRIPTION="backup system without creating rescue media"
 WORKFLOWS=( ${WORKFLOWS[@]} mkbackuponly )
 WORKFLOW_mkbackuponly () {
 	for arg in "${ARGS[@]}" ; do
@@ -12,19 +12,9 @@ WORKFLOW_mkbackuponly () {
 	done
 
 	SourceStage "prep"
-	
-	#SourceStage "dr"
-	
-	#SourceStage "rescue"
-	
-	#SourceStage "build"
-	
-	#SourceStage "pack"
-	
+
+	DISKLAYOUT_FILE=$TMP_DIR/backuplayout.conf
+	SourceStage "layout/save"
+
 	SourceStage "backup"
-	
-	#SourceStage "output"
-	
-	SourceStage "cleanup"
-	
 }
