@@ -1,24 +1,24 @@
 # mkrescue-workflow.sh
 #
-# mkrescue workflow for Relax & Recover
+# mkrescue workflow for Relax-and-Recover
 #
-#    Relax & Recover is free software; you can redistribute it and/or modify
+#    Relax-and-Recover is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
 #    the Free Software Foundation; either version 2 of the License, or
 #    (at your option) any later version.
 
-#    Relax & Recover is distributed in the hope that it will be useful,
+#    Relax-and-Recover is distributed in the hope that it will be useful,
 #    but WITHOUT ANY WARRANTY; without even the implied warranty of
 #    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #    GNU General Public License for more details.
 
 #    You should have received a copy of the GNU General Public License
-#    along with Relax & Recover; if not, write to the Free Software
+#    along with Relax-and-Recover; if not, write to the Free Software
 #    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #
 #
 
-WORKFLOW_mkrescue_DESCRIPTION="Create rescue media only"
+WORKFLOW_mkrescue_DESCRIPTION="create rescue media only"
 WORKFLOWS=( ${WORKFLOWS[@]} mkrescue )
 WORKFLOW_mkrescue () {
 	for arg in "${ARGS[@]}" ; do
@@ -29,17 +29,14 @@ WORKFLOW_mkrescue () {
 	done
 
 	SourceStage "prep"
-	
-	SourceStage "dr"
-	
+
+	SourceStage "layout/save"
+
 	SourceStage "rescue"
-	
+
 	SourceStage "build"
-	
+
 	SourceStage "pack"
 
 	SourceStage "output"
-	
-	SourceStage "cleanup"
-	
 }
