@@ -4,8 +4,11 @@
 # $ /opt/omni/bin/omnidb -filesystem | grep $(hostname)
 # test.internal.it3.be:/ '/'                                      FileSystem
 
-/opt/omni/bin/omnidb -filesystem | grep $(hostname) | cut -d"'" -f -2 > /tmp/list_of_fs_objects
-test -s /tmp/list_of_fs_objects || Error "Data Protector did not find any file system objects for $(hostname)"
+[ -f /tmp/DP_GUI_RESTORE ] && return # GUI restore explicetely requested
+
+/opt/omni/bin/omnidb -session $(cat /tmp/dp_recovery_session) | cut -d"'" -f -2 > /tmp/list_of_fs_objects
+[ -s /tmp/list_of_fs_objects ]
+StopIfError "Data Protector did not find any file system objects for $(hostname)"
 
 # check if we need to exclude a file system - exclude fs list =  $VAR_DIR/recovery/exclude_mountpoints
 if [ -f $VAR_DIR/recovery/exclude_mountpoints ]; then
